@@ -54,11 +54,15 @@ export const REFERENCE_TYPES = {
   TASK_SET: 'taskSet',
   TASK_NOT_COMPLETED_REASON: 'taskNotCompletedReason',
   TASK_DELETION_REASON: 'taskDeletionReason',
+  MEDICATION_NOT_GIVEN_REASON: 'medicationNotGivenReason',
+  MEDICATION_TEMPLATE: 'medicationTemplate',
+  MEDICATION_SET: 'medicationSet',
   ...IMAGING_AREA_TYPES,
 };
 export const REFERENCE_TYPE_VALUES = Object.values(REFERENCE_TYPES);
 
 // Reference data stored in its own table (not in 'reference_data' table)
+
 export const OTHER_REFERENCE_TYPES = {
   DEPARTMENT: 'department',
   FACILITY: 'facility',
@@ -70,7 +74,11 @@ export const OTHER_REFERENCE_TYPES = {
   PATIENT_FIELD_DEFINITION: 'patientFieldDefinition',
   PATIENT_FIELD_DEFININION_CATEGORY: 'patientFieldDefinitionCategory',
   SCHEDULED_VACCINE: 'scheduledVaccine',
+  PROGRAM_REGISTRY: 'programRegistry',
+  PROGRAM_REGISTRY_CLINICAL_STATUS: 'programRegistryClinicalStatus',
+  PROGRAM_REGISTRY_CONDITION: 'programRegistryCondition',
 };
+
 export const OTHER_REFERENCE_TYPE_VALUES = Object.values(OTHER_REFERENCE_TYPES);
 
 export const TRANSLATABLE_REFERENCE_TYPES = [
@@ -96,7 +104,9 @@ const SYSTEM_DATA_TYPES_VALUES = Object.values(SYSTEM_DATA_TYPES);
 
 export const GENERAL_IMPORTABLE_DATA_TYPES = [
   ...REFERENCE_TYPE_VALUES,
-  ...OTHER_REFERENCE_TYPE_VALUES,
+  ...OTHER_REFERENCE_TYPE_VALUES.filter(
+    (x) => x !== OTHER_REFERENCE_TYPES.PROGRAM_REGISTRY_CLINICAL_STATUS,
+  ),
   ...CLINICAL_DATA_TYPES_VALUES,
   ...SYSTEM_DATA_TYPES_VALUES,
 ].sort();
