@@ -1,6 +1,6 @@
 import express from 'express';
 import asyncHandler from 'express-async-handler';
-import { Op, QueryTypes } from 'sequelize';
+import { literal, QueryTypes, Op } from 'sequelize';
 import { snakeCase } from 'lodash';
 
 import { NotFoundError, InvalidParameterError } from '@tamanu/shared/errors';
@@ -8,6 +8,8 @@ import {
   PATIENT_REGISTRY_TYPES,
   VISIBILITY_STATUSES,
   IPS_REQUEST_STATUSES,
+  ENCOUNTER_TYPES,
+  DRUG_ROUTE_LABELS,
 } from '@tamanu/constants';
 import { isGeneratedDisplayId } from '@tamanu/utils/generateId';
 
@@ -23,7 +25,6 @@ import {
   patientProgramRegistration,
   patientProgramRegistrationConditions,
 } from './patientProgramRegistration';
-import { getOrderClause } from '../../../database/utils';
 import { dbRecordToResponse, pickPatientBirthData, requestBodyToRecord } from './utils';
 import { PATIENT_SORT_KEYS } from './constants';
 import { getWhereClausesAndReplacementsFromFilters } from '../../../utils/query';
@@ -193,63 +194,6 @@ patientRoute.get(
   }),
 );
 
-patientRoute.get(
-  '/:id/lastDischargedEncounter/medications',
-  asyncHandler(async (req, res) => {
-    const {
-      models: { Encounter, EncounterMedication },
-      params,
-      query,
-    } = req;
-
-    const { order = 'ASC', orderBy, rowsPerPage = 10, page = 0 } = query;
-
-    req.checkPermission('read', 'Patient');
-    req.checkPermission('read', 'Encounter');
-    req.checkPermission('list', 'EncounterMedication');
-
-    const lastDischargedEncounter = await Encounter.findOne({
-      where: {
-        patientId: params.id,
-        endDate: { [Op.not]: null },
-      },
-      order: [['endDate', 'DESC']],
-    });
-
-    // Return empty values if there isn't a discharged encounter
-    if (!lastDischargedEncounter) {
-      res.send({
-        count: 0,
-        data: [],
-      });
-      return;
-    }
-
-    // Find and return all associated encounter medications
-    const lastEncounterMedications = await EncounterMedication.findAndCountAll({
-      where: { encounterId: lastDischargedEncounter.id, isDischarge: true },
-      include: [
-        ...EncounterMedication.getFullReferenceAssociations(),
-        {
-          association: 'encounter',
-          include: [{ association: 'location', include: ['facility'] }],
-        },
-      ],
-      order: orderBy ? getOrderClause(order, orderBy) : undefined,
-      limit: rowsPerPage,
-      offset: page * rowsPerPage,
-    });
-
-    const { count } = lastEncounterMedications;
-    const data = lastEncounterMedications.rows.map((x) => x.forResponse());
-
-    res.send({
-      count,
-      data,
-    });
-  }),
-);
-
 patientRoute.get(
   '/$',
   asyncHandler(async (req, res) => {
@@ -530,6 +474,121 @@ patientRoute.post(
   }),
 );
 
+patientRoute.get(
+  '/:id/ongoing-prescriptions',
+  asyncHandler(async (req, res) => {
+    req.checkPermission('list', 'Medication');
+
+    const { models, params, query } = req;
+    const patientId = params.id;
+    const { PatientOngoingPrescription, Prescription } = models;
+    const { order = 'ASC', orderBy = 'medication.name', page, rowsPerPage } = query;
+
+    const baseQuery = {
+      include: [
+        ...Prescription.getListReferenceAssociations(),
+        {
+          model: PatientOngoingPrescription,
+          as: 'patientOngoingPrescription',
+          where: { patientId },
+        },
+      ],
+    };
+
+    const ongoingPrescriptions = await Prescription.findAll({
+      ...baseQuery,
+      order: [
+        [
+          literal('CASE WHEN "discontinued" IS NULL OR "discontinued" = false THEN 1 ELSE 0 END'),
+          'DESC',
+        ],
+        orderBy === 'route'
+          ? [
+              literal(
+                `CASE "route" ${Object.entries(DRUG_ROUTE_LABELS)
+                  .map(([value, label]) => `WHEN '${value}' THEN '${label}'`)
+                  .join(' ')} ELSE "route" END`,
+              ),
+              order.toUpperCase(),
+            ]
+          : [...orderBy.split('.'), order.toUpperCase()],
+      ],
+      ...(page && rowsPerPage
+        ? {
+            limit: rowsPerPage,
+            offset: page * rowsPerPage,
+          }
+        : {}),
+    });
+
+    const count = await Prescription.count({
+      ...baseQuery,
+    });
+
+    res.json({ data: ongoingPrescriptions, count });
+  }),
+);
+
+patientRoute.get(
+  '/:id/last-inpatient-discharge-medications',
+  asyncHandler(async (req, res) => {
+    const {
+      models: { Encounter, Discharge, Prescription, EncounterPrescription },
+      params,
+      query,
+    } = req;
+    const patientId = params.id;
+
+    req.checkPermission('list', 'Medication');
+
+    const { order = 'ASC', orderBy = 'medication.name' } = query;
+
+    const lastInpatientEncounter = await Encounter.findOne({
+      where: {
+        patientId,
+        encounterType: ENCOUNTER_TYPES.ADMISSION,
+        endDate: {
+          [Op.not]: null,
+        },
+      },
+      include: [
+        {
+          model: Discharge,
+          as: 'discharge',
+          attributes: ['facilityName'],
+        },
+      ],
+      order: [['endDate', 'DESC']],
+    });
+
+    if (!lastInpatientEncounter) {
+      res.json({ data: [], count: 0 });
+      return;
+    }
+
+    const dischargeMedications = await Prescription.findAll({
+      include: [
+        ...Prescription.getListReferenceAssociations(),
+        {
+          model: EncounterPrescription,
+          as: 'encounterPrescription',
+          where: {
+            isSelectedForDischarge: true,
+            encounterId: lastInpatientEncounter.id,
+          },
+        },
+      ],
+      order: [[...orderBy.split('.'), order.toUpperCase()]],
+    });
+
+    res.json({
+      data: dischargeMedications,
+      count: dischargeMedications.length,
+      lastInpatientEncounter,
+    });
+  }),
+);
+
 patientRoute.use(patientRelations);
 patientRoute.use(patientVaccineRoutes);
 patientRoute.use(patientDocumentMetadataRoutes);
